@@ -23,10 +23,11 @@ from __future__ import print_function
 import subprocess
 import threading
 import unicodedata
+from typing import Optional
 
 from com.dtmilano.android.adb.dumpsys import Dumpsys
 
-__version__ = '21.4.3'
+__version__ = '21.5.0'
 
 import sys
 import warnings
@@ -388,7 +389,8 @@ class AdbClient:
 
     def checkVersion(self, ignoreversioncheck=False, reconnect=True):
         if DEBUG:
-            print("checkVersion(reconnect=%s)   ignoreversioncheck=%s" % (reconnect, ignoreversioncheck), file=sys.stderr)
+            print("checkVersion(reconnect=%s)   ignoreversioncheck=%s" % (reconnect, ignoreversioncheck),
+                  file=sys.stderr)
         self.__send('host:version', reconnect=False)
         # HACK: MSG_WAITALL not available on windows
         # version = self.socket.recv(8, socket.MSG_WAITALL)
@@ -849,7 +851,8 @@ class AdbClient:
             if DEBUG:
                 if version == 1:
                     print("    takeSnapshot:", (
-                        version, bpp, size, width, height, roffset, rlen, boffset, blen, goffset, glen, aoffset, alen), file=sys.stderr)
+                        version, bpp, size, width, height, roffset, rlen, boffset, blen, goffset, glen, aoffset, alen),
+                          file=sys.stderr)
                 elif version == 2:
                     print("    takeSnapshot:", (
                         version, bpp, colorspace, width, height, roffset, rlen, boffset, blen, goffset, glen, aoffset,
@@ -952,21 +955,23 @@ class AdbClient:
 
     def touch(self, x, y, orientation=-1, eventType=DOWN_AND_UP):
         if DEBUG_TOUCH:
-            print("touch(x=", x, ", y=", y, ", orientation=", orientation, ", eventType=", eventType, ")", file=sys.stderr)
+            print("touch(x=", x, ", y=", y, ", orientation=", orientation, ", eventType=", eventType, ")",
+                  file=sys.stderr)
         self.__checkTransport()
         if orientation == -1:
             orientation = self.display['orientation']
         version = self.getSdkVersion()
         if version > 10:
             self.shell(
-                'input tap %d %d' % self.__transformPointByOrientation((x, y), orientation, self.display['orientation']))
+                'input tap %d %d' % self.__transformPointByOrientation((x, y), orientation,
+                                                                       self.display['orientation']))
         else:
             raise RuntimeError('drag: API <= 10 not supported (version=%d)' % version)
 
-
     def touchDip(self, x, y, orientation=-1, eventType=DOWN_AND_UP):
         if DEBUG_TOUCH:
-            print("touchDip(x=", x, ", y=", y, ", orientation=", orientation, ", eventType=", eventType, ")", file=sys.stderr)
+            print("touchDip(x=", x, ", y=", y, ", orientation=", orientation, ", eventType=", eventType, ")",
+                  file=sys.stderr)
         self.__checkTransport()
         if orientation == -1:
             orientation = self.display['orientation']
@@ -1082,7 +1087,7 @@ class AdbClient:
 
         self.__checkTransport()
         window_policy = self.shell('dumpsys window policy')
-              
+
         # Deprecated in API 20, removed in API 29
         screenOnRE = re.compile('mScreenOnFully=(true|false)')
         m = screenOnRE.search(window_policy)
@@ -1118,7 +1123,7 @@ class AdbClient:
         size_x1, size_y1 = image1.size
         size_x2, size_y2 = image2.size
         if (size_x1 != size_x2 or
-                    size_y1 != size_y2):
+                size_y1 != size_y2):
             return 0
 
         # Images are the same size
@@ -1214,7 +1219,8 @@ class AdbClient:
 
     def log(self, tag, message, priority='D', verbose=False):
         if DEBUG_LOG:
-            print("log(tag=%s, message=%s, priority=%s, verbose=%s)" % (tag, message, priority, verbose), file=sys.stderr)
+            print("log(tag=%s, message=%s, priority=%s, verbose=%s)" % (tag, message, priority, verbose),
+                  file=sys.stderr)
         self.__checkTransport()
         message = self.substituteDeviceTemplate(message)
         if verbose or priority == 'V':
@@ -1389,6 +1395,20 @@ class AdbClient:
         else:
             return None
 
+    def getTopActivityUri(self) -> Optional[str]:
+        tan = self.getTopActivityName()
+        dat = self.shell('dumpsys activity')
+        startActivityRE = re.compile(r'^\s*mStartActivity:')
+        intentRE = re.compile(f'^\\s*Intent {{ act=(\\S+) dat=(\\S+) flg=(\\S+) cmp={tan} }}')
+        lines = dat.splitlines()
+        for n, _line in enumerate(lines):
+            if startActivityRE.match(_line):
+                for i in range(n, n + 6):
+                    m = intentRE.match(lines[i])
+                    if m:
+                        return m.group(2)
+        return None
+
     def substituteDeviceTemplate(self, template):
         serialno = self.serialno.replace('.', '_').replace(':', '-')
         window_name = self.getFocusedWindowName() or 'no_name'
